@@ -1,5 +1,5 @@
 from exceptions import NoPlayerFoundError
-from hypixelaPY.objects.objects import HypixelPlayer
+from .objects.objects import HypixelPlayer
 import aiohttp
 
 HYPIXEL_API = "https://api.hypixel.net"
